@@ -244,7 +244,13 @@ def set_vars(
         logger.warning(f"envchain stderr (set):\n{stderr}")
 
 
-def set_var(namespace: str, key: str, value: str | None) -> None:
+def set_var(
+    namespace: str,
+    key: str,
+    value: str | None,
+    require_passphrase: bool = False,
+    envchain_cmd: str = DEFAULT_ENVCHAIN_COMMAND,
+) -> None:
     """
     Sets a single variable in the specified envchain namespace.
     This is a convenience wrapper around set_vars.
@@ -269,7 +275,12 @@ def set_var(namespace: str, key: str, value: str | None) -> None:
     if value is not None and not isinstance(value, str):
         raise TypeError("Value must be a string or None.")
 
-    set_vars(namespace, {key: value})  # Use the set_vars function for setting
+    set_vars(
+        namespace,
+        {key: value},
+        require_passphrase=require_passphrase,
+        envchain_cmd=envchain_cmd,
+    )  # Use the set_vars function for setting
     logger.info(f"Set variable '{key}' in envchain namespace '{namespace}'.")
     # No need to return anything; set_vars handles the operation
     return
